@@ -8,13 +8,16 @@ class StrEnum(str, Enum):
 
 class Pipeline(StrEnum):
     BALSAMIC: str = "balsamic"
+    BALSAMIC_QC: str = "balsamic-qc"
     BALSAMIC_UMI: str = "balsamic-umi"
+    BALSAMIC_PON: str = "balsamic-pon"
     DEMULTIPLEX: str = "demultiplex"
     FASTQ: str = "fastq"
     FLUFFY: str = "fluffy"
     MICROSALT: str = "microsalt"
     MIP_DNA: str = "mip-dna"
     MIP_RNA: str = "mip-rna"
+    RNAFUSION: str = "rnafusion"
     RSYNC: str = "rsync"
     SARS_COV_2: str = "sars-cov-2"
     SPRING: str = "spring"
